# gacha-elper

Small automation library to help automate repetitive tasks in mobile (Android) video games.

## Installation

You can install the package via `pip`

```bash
$ pip install gacha-elper
```

## Usage

```python
from gacha_elper.elper import Elper as Elp
from gacha_elper.elper import Coordinate as Coord
...
```

The library itself is very small. using `help()` for each module alone is enough to see how it works.
You can see `examples` to see it in more detail.

## License

see [LICENSE](https://github.com/cytopz/gacha-elper/blob/master/LICENSE)

## TODO

- [ ] Use my own implementation of template matching to actually make it small.
